@@ -62,7 +62,7 @@ CONFIG_FILE = '~/.bbrf/config.json'
 REGEX_DOMAIN = re.compile('^(?:[a-z0-9_](?:[a-z0-9-_]{0,61}[a-z0-9])?\\.)+[a-z0-9][a-z0-9-]{0,61}[a-z0-9]$')
 # regex to match IP addresses and CIDR ranges - thanks https://www.regextester.com/93987
 REGEX_IP = re.compile('^([0-9]{1,3}\\.){3}[0-9]{1,3}(/([0-9]|[1-2][0-9]|3[0-2]))?$')
-VERSION = '1.1.12'
+VERSION = '1.1.13'
 
 class BBRFClient:
     config = {}
@@ -741,7 +741,7 @@ class BBRFClient:
         self.api.update_document("program", program, {"disabled":False})
         
     def add_inscope(self, elements, passalong={}):
-        doc = passalong['doc'] if 'doc' in passalong else None
+        doc = passalong['doc'] if 'doc' in passalong else None  
         inscope = passalong['inscope'] if 'inscope' in passalong else None
         outscope = passalong['outscope'] if 'outscope' in passalong else None
         
@@ -755,6 +755,12 @@ class BBRFClient:
                 if REGEX_DOMAIN.match(e) or e.startswith('*.') and REGEX_DOMAIN.match(e[2:]):
                     changed = True
                     inscope.append(e)
+                # try to parse as a URL and consider the hostname as inscope
+                else:
+                    u = urlparse(e).hostname.lower()
+                    if u not in inscope and REGEX_DOMAIN.match(u):
+                        changed = True
+                        inscope.append(u)
         
         if changed:
             self.api.update_program_scope(self.get_program(), inscope, outscope, program=doc)
@@ -784,6 +790,12 @@ class BBRFClient:
                 if REGEX_DOMAIN.match(e) or e.startswith('*.') and REGEX_DOMAIN.match(e[2:]):
                     changed = True
                     outscope.append(e)
+                # try to parse as a URL and consider the hostname as outscope
+                else:
+                    u = urlparse(e).hostname.lower()
+                    if u not in inscope and REGEX_DOMAIN.match(u):
+                        changed = True
+                        outscope.append(u)
         
         if changed:
             self.api.update_program_scope(self.get_program(), inscope, outscope, program=doc)
